Get Traits in Clerc et al. 2018
traits_clerc_2018.RdThese traits are the ones used by Clerc et al. 2018 (https://doi.org/10.1053/j.gastro.2018.05.030). We generally don't recommend using these traits because they are either redundant or missing some important traits. We include this function because this paper is very influential in the field.
Usage of sialic acid linkage traits
To use these sialic acid linkage traits,
var_info of the input glyexp::experiment() must have the following columns:
nE: Number of a2,6-linked sialic acidsnL: Number of a2,3-linked sialic acids
Note that you have to add these two columns even if the glycan_structure column has intact linkages.
This is because by convention all traits work with glycan structures with "basic" structure levels
(i.e., with generic monosaccharides like "Hex" and "HexNAc" and no linkages specified).